@@ -6,12 +6,14 @@
 #'
 #' @param key The API key
 #' @param classifier_id The ID of the classifier
-#' @param verbose whether to output messages about batch requests
+#' @param texts_per_req Number of texts to be fed through per request (max 200). Does not affect output, but may affect speed of processing.
+#' @param verbose Whether to output messages about batch requests
+#' @param params Parameters for the module as a named list. See the second example.
 #'
 #' @details Find IDs of classifiers using \url{https://app.monkeylearn.com/main/explore}.
 #'
-#'  You can use batch to send up to 200 texts to be analyzed within the API
-#'  (classification or extraction) with each request.
+#' You can use batch to send up to 200 texts to be analyzed within the API
+#' (classification or extraction) with each request.
 #' So for example, if you need to analyze 6000 tweets,
 #' instead of doing 6000 requests to the API, you can use batch to send 30 requests,
 #' each request with 200 tweets.
@@ -21,7 +23,6 @@
 #' You can check the number of calls you can still make in the API using \code{attr(output, "headers")$x.query.limit.remaining}
 #' and \code{attr(output, "headers")$x.query.limit.limit}.
 #'
-#' @importFrom jsonlite toJSON
 #' @examples \dontrun{
 #' text1 <- "my dog is an avid rice eater"
 #' text2 <- "i want to buy an iphone"
@@ -32,40 +33,50 @@
 #' @return A data.frame (tibble) with the results whose attribute is a data.frame (tibble) "headers" including the number of remaining queries as "x.query.limit.remaining".
 #' Both data.frames include a column with the (list of) md5 checksum(s) of the corresponding text(s) computed using the \code{digest digest} function.
 #' @export
+
 monkeylearn_classify <- function(request, key = monkeylearn_key(quiet = TRUE),
                                  classifier_id = "cl_oFKL5wft",
-                                 verbose = FALSE) {
+                                 texts_per_req = 200,
+                                 verbose = TRUE,
+                                 params = NULL) {
+  if (verbose) {
+    message("This function is in the process of being deprecated. We suggest you switch to monkey_classify.
+More information available here: https://ropensci.github.io/monkeylearn/")
+  }
+
   # filter the blank requests
   length1 <- length(request)
   request <- monkeylearn_filter_blank(request)
-  if(length(request) == 0){
+  if (length(request) == 0) {
     warning("You only entered blank text in the request.", call. = FALSE)
     return(tibble::tibble())
-  }else{
-    if(length1 != length(request)){
+  } else {
+    if (length1 != length(request)) {
       message("The parts of your request that are only blank are not sent to the API.")
     }
     # 20 texts per request
-    request <- split(request, ceiling(seq_along(request)/20))
+    request <- split(request, ceiling(seq_along(request) / texts_per_req))
 
     results <- NULL
     headers <- NULL
 
-    for(i in seq_along(request)) {
-
-      if(verbose) {
+    for (i in seq_along(request)) {
+      if (verbose) {
         message(paste0("Processing request number ", i, " out of ", length(request)))
       }
 
       monkeylearn_text_size(request[[i]])
-      request_part <- monkeylearn_prep(request[[i]],
-                                       params = NULL)
+      request_part <- monkeylearn_prep(
+        request[[i]],
+        params
+      )
+
       output <- tryCatch(monkeylearn_get_classify(request_part, key, classifier_id))
       # for the case when the server returns nothing
       # try 5 times, not more
       try_number <- 1
-      while(class(output) == "try-error" && try_number < 6) {
-        message(paste0("Server returned nothing, trying again, try number", i))
+      while (class(output) == "try-error" && try_number < 6) {
+        message(paste0("Server returned nothing, trying again, try number", try_number))
         Sys.sleep(2^try_number)
         output <- tryCatch(monkeylearn_get_classify(request_part, key, classifier_id))
         try_number <- try_number + 1
@@ -74,22 +85,21 @@ monkeylearn_classify <- function(request, key = monkeylearn_key(quiet = TRUE),
       # check the output -- if it is 429 try again (throttle limit)
       # try 5 times, not more
       try_number <- 1
-      while(!monkeylearn_check(output) && try_number < 6) {
+      while (!monkeylearn_check(output, try_number, verbose) &&
+        try_number < 6) {
         output <- monkeylearn_get_classify(request_part, key, classifier_id)
         try_number <- try_number + 1
       }
       # parse output
       output <- monkeylearn_parse(output, request_text = request[[i]])
 
-      results <- suppressWarnings(rbind(results, output$results))
-
-      headers <- suppressWarnings(rbind(headers,
-                                        output$headers[, names(output$headers) %in% names(headers)]))
+      results <- suppressWarnings(dplyr::bind_rows(results, output$results))
+      headers <- suppressWarnings(dplyr::bind_rows(headers, output$headers))
     }
 
     # done!
     results <- tibble::as_tibble(results)
-    attr(results, "headers") <-  tibble::as_tibble(headers)
+    attr(results, "headers") <- tibble::as_tibble(headers)
     results
   }
 }
