@@ -6,10 +6,10 @@
 #'
 #' @param key The API key
 #' @param extractor_id The ID of the extractor
-#' @param verbose whether to output messages about batch requests
-#' @param params parameters for the module as a named list. See the second example.
+#' @param texts_per_req Number of texts to be fed through per request (max 200). Does not affect output, but may affect speed of processing.
+#' @param verbose Whether to output messages about batch requests
+#' @param params Parameters for the module as a named list. See the second example.
 #'
-#' @importFrom jsonlite toJSON
 #' @examples \dontrun{
 #' text <- "In the 19th century, the major European powers had gone to great lengths
 #' to maintain a balance of power throughout Europe, resulting in the existence of
@@ -25,15 +25,12 @@
 #' Columbia University faculty club trying to convince a packed room of potential
 #' recruits that Wall Street, not Silicon Valley, was the place to be for computer
 #' scientists.\n\n The Goldman employees knew they had an uphill battle. They were
-#'  fighting against perceptions of Wall Street as boring and regulation-bound and
-#'  Silicon Valley as the promised land of flip-flops, beanbag chairs and million-dollar
-#'   stock options.\n\n Their argument to the room of technologically inclined students
-#'   was that Wall Street was where they could find far more challenging, diverse and,
-#'    yes, lucrative jobs working on some of the worlds most difficult technical problems.\n\n
-#'    Whereas in other opportunities you might be considering, it is working one type of data
-#'    or one type of application, we deal in hundreds of products in hundreds of markets, with
-#'     thousands or tens of thousands of clients, every day, millions of times of day worldwide,
-#'      Afsheen Afshar, a managing director at Goldman Sachs, told the students."
+#' fighting against perceptions of Wall Street as boring and regulation-bound and
+#' Silicon Valley as the promised land of flip-flops, beanbag chairs and million-dollar
+#' stock options.\n\n Their argument to the room of technologically inclined students
+#' was that Wall Street was where they could find far more challenging, diverse and,
+#' yes, lucrative jobs working on some of the worlds most difficult technical problems."
+#'
 #' output <- monkeylearn_extract(text,
 #'                               extractor_id = "ex_y7BPYzNG",
 #'                               params = list(max_keywords = 3,
@@ -42,8 +39,8 @@
 #' @details Find IDs of extractors using \url{https://app.monkeylearn.com/main/explore}.
 #' Within the free plan, you can make up to 20 requests per minute.
 #'
-#'   You can use batch to send up to 200 texts to be analyzed within the API
-#'  (classification or extraction) with each request.
+#' You can use batch to send up to 200 texts to be analyzed within the API
+#' (classification or extraction) with each request.
 #' So for example, if you need to analyze 6000 tweets,
 #' instead of doing 6000 requests to the API, you can use batch to send 30 requests,
 #' each request with 200 tweets.
@@ -56,50 +53,61 @@
 #' @return A data.frame with the results whose attribute is a data.frame (tibble) "headers" including the number of remaining queries as "x.query.limit.remaining".
 #' Both data.frames include a column with the (list of) md5 checksum(s) of the corresponding text(s) computed using the \code{digest digest} function.
 #' @export
+
 monkeylearn_extract <- function(request, key = monkeylearn_key(quiet = TRUE),
                                 extractor_id = "ex_isnnZRbS",
-                                verbose = FALSE,
+                                texts_per_req = 200,
+                                verbose = TRUE,
                                 params = NULL) {
+  if (verbose) {
+    message("This function is in the process of being deprecated. We suggest you switch to monkey_extract.
+More information available here: https://ropensci.github.io/monkeylearn/")
+  }
 
   # filter the blank requests
   length1 <- length(request)
   request <- monkeylearn_filter_blank(request)
-  if(length(request) == 0){
+  if (length(request) == 0) {
     warning("You only entered blank text in the request.", call. = FALSE)
     return(tibble::tibble())
-  }else{
-    if(length1 != length(request)){
+  } else {
+    if (length1 != length(request)) {
       message("The parts of your request that are only blank are not sent to the API.")
     }
 
     # 20 texts per request
-    request <- split(request, ceiling(seq_along(request)/20))
+    request <- split(request, ceiling(seq_along(request) / texts_per_req))
 
     results <- NULL
     headers <- NULL
 
-    for(i in seq_along(request)) {
-      if(verbose) {
+    for (i in seq_along(request)) {
+      if (verbose) {
         message(paste0("Processing request number ", i, " out of ", length(request)))
       }
 
       monkeylearn_text_size(request[[i]])
-      request_part <- monkeylearn_prep(request[[i]],
-                                       params)
+      request_part <- monkeylearn_prep(
+        request[[i]],
+        params
+      )
       output <- tryCatch(monkeylearn_get_extractor(request_part, key, extractor_id))
       # for the case when the server returns nothing
       # try 5 times, not more
       try_number <- 1
-      while(class(output) == "try-error" && try_number < 6) {
-        message(paste0("Server returned nothing, trying again, try number", i))
+      while (class(output) == "try-error" && try_number < 6) {
+        message(paste0("Server returned nothing, trying again, try number", try_number))
         Sys.sleep(2^try_number)
         output <- tryCatch(monkeylearn_get_extractor(request_part, key, extractor_id))
         try_number <- try_number + 1
       }
 
-      # check the output -- if it is 429 try again (throttle limit)
-      while(!monkeylearn_check(output)) {
+      # check the output
+      try_number <- 1
+      while (!monkeylearn_check(output, try_number, verbose) &&
+        try_number < 6) {
         output <- monkeylearn_get_extractor(request_part, key, extractor_id)
+        try_number <- try_number + 1
       }
       # parse output
       output <- monkeylearn_parse(output, request_text = request[[i]])
@@ -109,10 +117,7 @@ monkeylearn_extract <- function(request, key = monkeylearn_key(quiet = TRUE),
     }
 
     # done!
-    attr(results, "headers") <-  tibble::as_tibble(headers)
+    attr(results, "headers") <- tibble::as_tibble(headers)
     results
   }
-
-
 }
-
